@@ -1,7 +1,7 @@
 #!/usr/bin/perl -w
 #use strict;
 use warnings;
-use SOAP::Lite +trace;
+use SOAP::Lite; # +trace;
 
 # I have to lookup the URL from the WSDL
 my $soap = SOAP::Lite->new(
@@ -25,5 +25,5 @@ my $som = $soap->call(
 
 die $som->fault->{ faultstring } if ($som->fault);
 
-print $som->result, "\n";
+print $som->result(), "\n";
 
