@@ -2,6 +2,7 @@ package SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
 use strict;
 use warnings;
 use Class::Std::Fast::Storable constructor => 'none', cache => 1;
+use SOAP::WSDL::XSD::Typelib::Builtin::anyType;
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
 my %value_of :ATTR(:get<value> :init_arg<value> :default<()>);
@@ -9,10 +10,25 @@ my %value_of :ATTR(:get<value> :init_arg<value> :default<()>);
 # don't you never dare to play with this !
 our $___value = \%value_of;
 
+sub get_xmltype { 
+    my $class = ref $_[0];
+    if ($class =~s{^SOAP::WSDL::XSD::Typelib::Builtin::}{}x) {
+        return $class;
+    }
+    else {
+        die "You must override get_xmltype in $class";
+    }
+}
+
 ## use $_[n] for speed - we get called zillions of times...
 # and we don't need to return the last value...
 sub set_value { $value_of{ ${ $_[0] } } = $_[1] }
 
+# Default attribute handling
+# TODO add something for handling default attributes
+sub attr {
+}
+
 # use $_[n] for speed.
 # This is less readable, but notably faster.
 #
@@ -23,8 +39,10 @@ sub set_value { $value_of{ ${ $_[0] } } = $_[1] }
 # every little statement matters...
 
 sub serialize {
-    no warnings qw(uninitialized);
-    $_[1]->{ nil } = 1 if not defined $value_of{ ${$_[0]} };
+    $_[1] ||= {};
+    if (not defined $value_of{ ${$_[0]} }) {
+        return $_[0]->start_tag({ %{ $_[1] },  nil => 1 }, undef);
+    }
     return join q{}
         , $_[0]->start_tag($_[1], $value_of{ ${$_[0]} })
         , $value_of{ ${$_[0]} }
@@ -32,14 +50,13 @@ sub serialize {
 }
 
 sub as_string :STRINGIFY {
-    return $value_of { ${ $_[0] } };
+    return defined($value_of { ${ $_[0] } }) ? $value_of { ${ $_[0] } } : q{};
 }
 
 sub as_bool :BOOLIFY {
     return $value_of { ${ $_[0] } };
 }
 
-my $ID_GENERATOR_REF = Class::Std::Fast::ID_GENERATOR_REF();
 my $OBJECT_CACHE_REF = Class::Std::Fast::OBJECT_CACHE_REF();
 
 sub new {
@@ -51,6 +68,6 @@ sub new {
     return $self;
 }
 
-Class::Std::Fast::initialize();   # make :BOOLIFY overloading serializable
+Class::Std::initialize();   # make :BOOLIFY overloading serializable
 
 1;
