@@ -12,6 +12,8 @@ my %char2entity = (
     q{'} => q{&apos;},
 );
 
+# sub get_xmltype { "xs:string" }
+
 sub serialize {
     $_[1] ||= {};
 
@@ -33,5 +35,5 @@ sub as_bool :BOOLIFY {
     return $_[0]->get_value();
 }
 
-Class::Std::initialize;
+Class::Std::initialize();
 1;
